@@ -38,9 +38,6 @@ class ExtendedAnnotator:
     modified_by: Union[Unset, str] = UNSET
     modified_at: Union[Unset, str] = UNSET
 
-    def __hash__(self):
-        return hash((self.name, self.type))
-
     def to_dict(self) -> Dict[str, Any]:
         name = self.name
         label = self.label
@@ -138,9 +135,6 @@ class StreamlitSherpaClient:
         self.client.login(Credentials(email=user, password=password),
                           project_access_mode=RequestJwtTokenProjectAccessMode.READ)
 
-    def __hash__(self):
-        return hash(self.client.token)
-
     def get_projects(self) -> List[ProjectBean]:
         r = get_projects.sync_detailed(client=self.client)
         if r.is_success:
