@@ -20,16 +20,24 @@ DEBUG = True
 
 
 def ProjectBean_hash(self):
-    return hash(self.name)
+    return self.name
 
 
 def Document_hash(self):
-    return hash(self.text)
+    return self.text
+
+
+def StreamlitSherpaClient_hash(self):
+    return self.client.token
+
+
+def ExtendedAnnotator_hash(self):
+    return (self.name, self.type)
 
 
 HASH_FUNCS = {
-    "sherpa_streamlit.sherpa.StreamlitSherpaClient": hash,
-    "sherpa_streamlit.sherpa.ExtendedAnnotator": hash,
+    "sherpa_streamlit.sherpa.StreamlitSherpaClient": StreamlitSherpaClient_hash,
+    "sherpa_streamlit.sherpa.ExtendedAnnotator": ExtendedAnnotator_hash,
     "sherpa_client.models.ProjectBean": ProjectBean_hash,
     "sherpa_client.models.Document": Document_hash
 }
@@ -63,7 +71,8 @@ def get_cached_annotator_by_label(client, project: str, label: str,
                                   annotator_types: Tuple[str] = None,
                                   favorite_only: bool = False):
     if DEBUG:
-        st.write("Cache miss: get_cached_annotator_by_label(", client, ",", project, ",", annotator_types, ",",
+        st.write("Cache miss: get_cached_annotator_by_label(", client, ",", project, ",", label, ",",
+                 annotator_types, ",",
                  favorite_only, ") ran")
     annotators = get_cached_annotators(client, project, annotator_types, favorite_only)
     for ann in annotators:
